@@ -4,8 +4,10 @@ use strict;
 use File::Find::Object;
 use File::Spec::Functions qw(catfile);
 use File::stat;
+use ExtUtils::Manifest qw(skipcheck);
+$ExtUtils::Manifest::Quiet = 1;
 
-our $VERSION = '0.97_03';
+our $VERSION = '0.97_04';
 $VERSION =~ s/_//; ## no critic
 
 sub order { 15 }
@@ -22,6 +24,7 @@ sub analyse {
 
     # Respect no_index if possible
     my $no_index_re = $class->_make_no_index_regex($me);
+    my %maniskip = map { $_ => 1 } skipcheck;
 
     my (%files, %dirs);
     my (@files_array, @dirs_array);
@@ -36,6 +39,7 @@ sub analyse {
         $name =~ s|\\|/|g if $^O eq 'MSWin32';
         (my $path = $name) =~ s!^\Q$distdir\E(?:/|$)!! or next;
         next if $path eq '';
+        next if $maniskip{$path};
         next if $seen{$path}++;
 
         if (-d $name) {
@@ -369,11 +373,11 @@ Returns C<15>, as data generated by C<MCK::Files> is used by all other tests.
 
 =head3 analyse
 
-C<MCK::Files> uses C<File::Find::Object> to get a list of all files and dirs in a dist. It checks if certain crucial files are there, and does some other file-specific stuff.
+C<MCK::Files> uses C<File::Find::Object> to get a list of all files and directories in a distribution. It checks if certain crucial files are there, and does some other file-specific stuff.
 
 =head3 kwalitee_indicators
 
-Returns the Kwalitee Indicators datastructure.
+Returns the Kwalitee Indicators data structure.
 
 =over
 
